searchData={"items":[{"type":"module","title":"Want","doc":"Type conversion library for Elixir and Erlang. Want allows you to convert between Elixir and Erlang types using an intuitive interface. In\r\naddition, Elixir users have access to more complex type conversion via the `Want.map/3`, `Want.keywords/3` and `Want.Shape` functions and\r\nmacros.","ref":"Want.html"},{"type":"function","title":"Want.atom/1","doc":"Cast a value to an atom.","ref":"Want.html#atom/1"},{"type":"function","title":"Options - Want.atom/1","doc":"* `:exists` - If true, only convert to an atom if a matching atom already exists.\r\n  * `:default` - If conversion fails, this value should be returned instead.","ref":"Want.html#atom/1-options"},{"type":"function","title":"Examples - Want.atom/1","doc":"iex> Want.atom(\"hello\")\r\n    {:ok, :hello}\r\n\r\n    iex> Want.atom(1.0)\r\n    {:ok, :'1.0'}\r\n\r\n    iex> Want.atom({:a, :b})\r\n    {:error, \"Failed to convert value {:a, :b} to atom.\"}\r\n\r\n    iex> Want.atom({:a, :b}, default: :c)\r\n    {:ok, :c}\r\n\r\n    iex> Want.atom(\"10\", exists: true)\r\n    {:error, \"An atom matching the given value does not exist.\"}","ref":"Want.html#atom/1-examples"},{"type":"function","title":"Want.atom/2","doc":"","ref":"Want.html#atom/2"},{"type":"function","title":"Want.atom!/1","doc":"","ref":"Want.html#atom!/1"},{"type":"function","title":"Want.atom!/2","doc":"","ref":"Want.html#atom!/2"},{"type":"function","title":"Want.boolean/1","doc":"Cast a value to a boolean.","ref":"Want.html#boolean/1"},{"type":"function","title":"Options - Want.boolean/1","doc":"* `:default` - If conversion fails, this value should be returned instead.","ref":"Want.html#boolean/1-options"},{"type":"function","title":"Examples - Want.boolean/1","doc":"iex> Want.boolean(\"true\")\r\n    {:ok, true}\r\n\r\n    iex> Want.boolean(\"FALSE\")\r\n    {:ok, false}\r\n\r\n    iex> Want.boolean(1.0)\r\n    {:ok, true}\r\n\r\n    iex> Want.boolean({:a, :b})\r\n    {:error, \"Failed to convert value {:a, :b} to boolean.\"}\r\n\r\n    iex> Want.boolean({:a, :b}, default: true)\r\n    {:ok, true}","ref":"Want.html#boolean/1-examples"},{"type":"function","title":"Want.boolean/2","doc":"","ref":"Want.html#boolean/2"},{"type":"function","title":"Want.boolean!/1","doc":"","ref":"Want.html#boolean!/1"},{"type":"function","title":"Want.boolean!/2","doc":"","ref":"Want.html#boolean!/2"},{"type":"function","title":"Want.check_type!/1","doc":"Check whether the given type name is valid and raise if not.","ref":"Want.html#check_type!/1"},{"type":"function","title":"Want.datetime/1","doc":"Cast an incoming value to a datetime.","ref":"Want.html#datetime/1"},{"type":"function","title":"Examples - Want.datetime/1","doc":"iex> Want.datetime(\"2020-02-06 18:23:55.850218Z\")\r\n    {:ok, ~U[2020-02-06 18:23:55.850218Z]}\r\n\r\n    iex> Want.datetime({{2020, 02, 06}, {18, 23, 55}})\r\n    {:ok, ~U[2020-02-06 18:23:55Z]}\r\n\r\n    iex> Want.datetime({{2020, 02, 06}, {18, 23, 55, 123456}})\r\n    {:ok, ~U[2020-02-06 18:23:55.123456Z]}","ref":"Want.html#datetime/1-examples"},{"type":"function","title":"Want.datetime/2","doc":"","ref":"Want.html#datetime/2"},{"type":"function","title":"Want.datetime!/1","doc":"","ref":"Want.html#datetime!/1"},{"type":"function","title":"Want.datetime!/2","doc":"","ref":"Want.html#datetime!/2"},{"type":"function","title":"Want.dump/1","doc":"Dump a casted input into a more serializable form. Typically used to generate\r\nPhoenix query parameters.","ref":"Want.html#dump/1"},{"type":"function","title":"Options - Want.dump/1","doc":"* `:update` - Update the input value using Want.Update protocol before dumping","ref":"Want.html#dump/1-options"},{"type":"function","title":"Examples - Want.dump/1","doc":"iex> Want.dump({:inserted_at, :desc})\r\n    {:ok, \"inserted_at:desc\"}\r\n\r\n    iex> Want.dump({:inserted_at, :desc}, update: :inserted_at)\r\n    {:ok, \"inserted_at:asc\"}\r\n\r\n    iex> Want.dump({:inserted_at, :desc}, update: :updated_at)\r\n    {:ok, \"updated_at:asc\"}\r\n\r\n    iex> Want.dump(\"hello\")\r\n    {:ok, \"hello\"}\r\n\r\n    iex> Want.dump(%{hello: :world, sort: {:inserted_at, :desc}})\r\n    {:ok, [hello: :world, sort: \"inserted_at:desc\"]}\r\n\r\n    iex> Want.dump(%{hello: :world, sort: {:inserted_at, :desc}}, update: [sort: :inserted_at])\r\n    {:ok, [hello: :world, sort: \"inserted_at:asc\"]}\r\n\r\n    iex> Want.dump({:a, :b, :c})\r\n    {:error, \"Unrecognized dump input {:a, :b, :c}\"}","ref":"Want.html#dump/1-examples"},{"type":"function","title":"Want.dump/2","doc":"","ref":"Want.html#dump/2"},{"type":"function","title":"Want.dump!/1","doc":"","ref":"Want.html#dump!/1"},{"type":"function","title":"Want.dump!/2","doc":"","ref":"Want.html#dump!/2"},{"type":"function","title":"Want.enum/2","doc":"Cast an input value to an enum. The input must loosely match one of the allowed values in order for\r\nthe cast to succeed.","ref":"Want.html#enum/2"},{"type":"function","title":"Options - Want.enum/2","doc":"* `:valid` - List of valid enum values. The input must loosely match one of these.\r\n  * `:default` - If conversion fails, this value should be returned instead.","ref":"Want.html#enum/2-options"},{"type":"function","title":"Examples - Want.enum/2","doc":"iex> Want.enum(\"hello\", valid: [:hello, :world])\r\n    {:ok, :hello}\r\n\r\n    iex> Want.enum(\"hello\", valid: [\"hello\", :world])\r\n    {:ok, \"hello\"}\r\n\r\n    iex> Want.enum(\"foo\", valid: [\"hello\", :world], default: :bar)\r\n    {:ok, :bar}","ref":"Want.html#enum/2-examples"},{"type":"function","title":"Want.enum!/2","doc":"","ref":"Want.html#enum!/2"},{"type":"function","title":"Want.float/1","doc":"Convert a value to a float.","ref":"Want.html#float/1"},{"type":"function","title":"Options - Want.float/1","doc":"* `:max` - Maximum allowable float value.\r\n  * `:min` - Minimum allowable float value.\r\n  * `:default` - If conversion fails, this value should be returned instead.","ref":"Want.html#float/1-options"},{"type":"function","title":"Examples - Want.float/1","doc":"iex> Want.float(1.0)\r\n    {:ok, 1.0}\r\n\r\n    iex> Want.float({:a, :b}, default: 1.0)\r\n    {:ok, 1.0}\r\n\r\n    iex> Want.float(:'5.0', max: 3.0)\r\n    {:error, \"Float value exceeds maximum 3.0.\"}\r\n\r\n    iex> Want.float(\"1.0\", min: 3.0)\r\n    {:error, \"Float value below minimum 3.0.\"}","ref":"Want.html#float/1-examples"},{"type":"function","title":"Want.float/2","doc":"","ref":"Want.html#float/2"},{"type":"function","title":"Want.float!/1","doc":"","ref":"Want.html#float!/1"},{"type":"function","title":"Want.float!/2","doc":"","ref":"Want.html#float!/2"},{"type":"function","title":"Want.integer/1","doc":"Convert a value to an integer.","ref":"Want.html#integer/1"},{"type":"function","title":"Options - Want.integer/1","doc":"* `:max` - Maximum allowable integer value.\r\n  * `:min` - Minimum allowable integer value.\r\n  * `:default` - If conversion fails, this value should be returned instead.","ref":"Want.html#integer/1-options"},{"type":"function","title":"Examples - Want.integer/1","doc":"iex> Want.integer(1.0)\r\n    {:ok, 1}\r\n\r\n    iex> Want.integer({:a, :b}, default: 1)\r\n    {:ok, 1}\r\n\r\n    iex> Want.integer(:'5', max: 3)\r\n    {:error, \"Integer value exceeds maximum 3.\"}\r\n\r\n    iex> Want.integer(\"1\", min: 3)\r\n    {:error, \"Integer value below minimum 3.\"}","ref":"Want.html#integer/1-examples"},{"type":"function","title":"Want.integer/2","doc":"","ref":"Want.html#integer/2"},{"type":"function","title":"Want.integer!/1","doc":"","ref":"Want.html#integer!/1"},{"type":"function","title":"Want.integer!/2","doc":"","ref":"Want.html#integer!/2"},{"type":"function","title":"Want.is_valid_type?/1","doc":"Determine whether the given type name is valid.","ref":"Want.html#is_valid_type?/1"},{"type":"function","title":"Want.keywords/3","doc":"Cast an incoming keyword list or map to an output keyword list using the provided schema to control\r\nconversion rules and validations. Each value in the schema map represents conversion options.\r\n\r\nSpecify a :type field to cast the input value for a given key to that type, defaults to :string.\r\nSpecific conversion and validation options for each type corresponds to those available\r\nfor `Want.integer/2`, `Want.float/2`, `Want.string/2` and `Want.atom/2`.\r\n\r\nKeyword lists can be nested by using a new schema map as a value in a parent schema. The field from which\r\na given value is derived can also be modified using the `:from` option.","ref":"Want.html#keywords/3"},{"type":"function","title":"Examples - Want.keywords/3","doc":"iex> Want.keywords(%{\"id\" => 1}, %{id: [type: :integer]})\r\n    {:ok, [id: 1]}\r\n\r\n    iex> Want.keywords(%{\"identifier\" => 1}, %{id: [type: :integer, from: :identifier]})\r\n    {:ok, [id: 1]}\r\n\r\n    iex> Want.keywords(%{}, %{id: [type: :integer, default: 1]})\r\n    {:ok, [id: 1]}\r\n\r\n    iex> Want.keywords(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]})\r\n    {:ok, [id: 1]}\r\n\r\n    iex> Want.keywords(%{\"identifier\" => \"bananas\"}, %{id: [type: :integer, default: 1, from: :identifier]})\r\n    {:ok, [id: 1]}\r\n\r\n    iex> Want.keywords(%{\"hello\" => \"world\", \"foo\" => \"bar\"}, %{hello: [], foo: [type: :atom]})\r\n    {:ok, [hello: \"world\", foo: :bar]}\r\n\r\n    iex> Want.keywords(%{\"hello\" => %{\"foo\" => \"bar\"}}, %{hello: %{foo: [type: :atom]}})\r\n    {:ok, [hello: [foo: :bar]]}\r\n\r\n    iex> Want.keywords(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]}, merge: [id: 2])\r\n    {:ok, [id: 2]}","ref":"Want.html#keywords/3-examples"},{"type":"function","title":"Want.keywords!/3","doc":"","ref":"Want.html#keywords!/3"},{"type":"function","title":"Want.list/2","doc":"Cast an input into a list. By default this function will simply break up the input into list elements, but\r\nfurther casting and validation of elements can be performed by providing an `element` option. The separator\r\nused to split the list defaults to the comma character and this can be controlled using the `separator` option.","ref":"Want.html#list/2"},{"type":"function","title":"Options - Want.list/2","doc":"* `:separator` - Determines the character(s) used to separate list items. Defaults to the comma character.\r\n  * `:element` - Provides the ability to further control how list elements are cast and validated. Similar to the\r\n  `map` and `keywords` functions, accepts a keyword list with its own `:type` field and validation options.\r\n  * `:default` - If conversion fails, this value should be returned instead.","ref":"Want.html#list/2-options"},{"type":"function","title":"Examples - Want.list/2","doc":"iex> Want.list(\"1\")\r\n    {:ok, [\"1\"]}\r\n\r\n    iex> Want.list(\"1\", element: [type: :integer])\r\n    {:ok, [1]}\r\n\r\n    iex> Want.list(\"1,2,3,4\", element: [type: :integer])\r\n    {:ok, [1, 2, 3, 4]}\r\n\r\n    iex> Want.list(\"1:2:3:4\", separator: \":\", element: [type: :integer])\r\n    {:ok, [1, 2, 3, 4]}\r\n\r\n    iex> Want.list(\"hello:world\", separator: \":\", element: [type: :enum, valid: [:hello, :world]])\r\n    {:ok, [:hello, :world]}\r\n\r\n    iex> Want.list(\"hello:world\", separator: \":\", element: [type: :enum, valid: [:hello]])\r\n    {:ok, [:hello]}","ref":"Want.html#list/2-examples"},{"type":"function","title":"Want.list!/2","doc":"","ref":"Want.html#list!/2"},{"type":"function","title":"Want.map/3","doc":"Cast an incoming keyword list or map to an output map using the\r\nprovided schema to control conversion rules and validations. Each value in\r\nthe schema map represents conversion options.\r\n\r\nSpecify a :type field to cast the input value for a given key to that type, defaults to :string.\r\nSpecific conversion and validation options for each type corresponds to those available\r\nfor `Want.integer/2`, `Want.float/2`, `Want.string/2` and `Want.atom/2`.\r\n\r\nMaps can be nested by using a new schema map as a value in a parent schema. The field from which\r\na given value is derived can also be modified using the `:from` option.","ref":"Want.html#map/3"},{"type":"function","title":"Options - Want.map/3","doc":"* `:merge` - Provide a map matching the given schema that contains default values to be\r\n    used if the input value does not contain a particular field. Useful when updating a map\r\n    with new inputs without overwriting all fields.","ref":"Want.html#map/3-options"},{"type":"function","title":"Examples - Want.map/3","doc":"iex> Want.map(%{\"id\" => 1}, %{id: [type: :integer]})\r\n    {:ok, %{id: 1}}\r\n\r\n    iex> Want.map(%{\"identifier\" => 1}, %{id: [type: :integer, from: :identifier]})\r\n    {:ok, %{id: 1}}\r\n\r\n    iex> Want.map(%{}, %{id: [type: :integer, default: 1]})\r\n    {:ok, %{id: 1}}\r\n\r\n    iex> Want.map(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]})\r\n    {:ok, %{id: 1}}\r\n\r\n    iex> Want.map(%{\"hello\" => \"world\", \"foo\" => \"bar\"}, %{hello: [], foo: [type: :atom]})\r\n    {:ok, %{hello: \"world\", foo: :bar}}\r\n\r\n    iex> Want.map(%{\"hello\" => %{\"foo\" => \"bar\"}}, %{hello: %{foo: [type: :atom]}})\r\n    {:ok, %{hello: %{foo: :bar}}}\r\n\r\n    iex> Want.map(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]}, merge: %{id: 2})\r\n    {:ok, %{id: 2}}","ref":"Want.html#map/3-examples"},{"type":"function","title":"Want.map!/3","doc":"","ref":"Want.html#map!/3"},{"type":"function","title":"Want.sort/2","doc":"Cast an input to a sort tuple.","ref":"Want.html#sort/2"},{"type":"function","title":"Options - Want.sort/2","doc":"* `:fields` - List of allowed sort fields. Casting will fail if the input doesn't match any of these.\r\n  * `:default` - If conversion fails, this value should be returned instead.","ref":"Want.html#sort/2-options"},{"type":"function","title":"Examples - Want.sort/2","doc":"iex> Want.sort(\"inserted_at:desc\", fields: [:inserted_at, :id, :name])\r\n    {:ok, {:inserted_at, :desc}}\r\n\r\n    iex> Want.sort(\"updated_at\", fields: [:inserted_at, :id], default: {:id, :asc})\r\n    {:ok, {:id, :asc}}\r\n\r\n    iex> Want.sort(\"updated_at:asc\", [])\r\n    {:error, \"You must specify a list of valid sort fields using the :fields option.\"}","ref":"Want.html#sort/2-examples"},{"type":"function","title":"Want.sort!/2","doc":"","ref":"Want.html#sort!/2"},{"type":"function","title":"Want.string/1","doc":"Convert a value to a string.","ref":"Want.html#string/1"},{"type":"function","title":"Options - Want.string/1","doc":"* `:max` - Maximum allowable string length.\r\n  * `:min` - Minimum allowable string length.\r\n  * ':decode' - Currently only supports :uri; runs URI.decode on the input value\r\n  * `:matches` - The resulting string must match the given regex.\r\n  * `:default` - If conversion fails, this value should be returned instead.","ref":"Want.html#string/1-options"},{"type":"function","title":"Examples - Want.string/1","doc":"iex> Want.string(1)\r\n    {:ok, \"1\"}\r\n\r\n    iex> Want.string({:a, :b}, default: \"string\")\r\n    {:ok, \"string\"}\r\n\r\n    iex> Want.string(:hello, max: 3)\r\n    {:error, \"String length exceeds maximum of 3.\"}\r\n\r\n    iex> Want.string(\"hello%20world\", decode: :uri)\r\n    {:ok, \"hello world\"}\r\n\r\n    iex> Want.string(:a, min: 3)\r\n    {:error, \"String length below minimum of 3.\"}\r\n\r\n    iex> Want.string(:a, matches: ~r/a/)\r\n    {:ok, \"a\"}","ref":"Want.html#string/1-examples"},{"type":"function","title":"Want.string/2","doc":"","ref":"Want.html#string/2"},{"type":"function","title":"Want.string!/1","doc":"","ref":"Want.html#string!/1"},{"type":"function","title":"Want.string!/2","doc":"","ref":"Want.html#string!/2"},{"type":"function","title":"Want.valid_types/0","doc":"Return a list of atoms describing the types that `Want` recognizes.","ref":"Want.html#valid_types/0"},{"type":"type","title":"Want.enumerable/0","doc":"","ref":"Want.html#t:enumerable/0"},{"type":"module","title":"Want.Any","doc":"","ref":"Want.Any.html"},{"type":"module","title":"Want.Atom","doc":"Performs type conversions to atom values.","ref":"Want.Atom.html"},{"type":"function","title":"Want.Atom.cast/1","doc":"Cast a value to an atom.","ref":"Want.Atom.html#cast/1"},{"type":"function","title":"Options - Want.Atom.cast/1","doc":"* `:exists` - If true, only convert to an atom if a matching atom already exists.","ref":"Want.Atom.html#cast/1-options"},{"type":"function","title":"Examples - Want.Atom.cast/1","doc":"iex> Want.Atom.cast(\"hello\")\r\n    {:ok, :hello}\r\n\r\n    iex> Want.Atom.cast(1.0)\r\n    {:ok, :'1.0'}\r\n\r\n    iex> Want.Atom.cast({:a, :b})\r\n    {:error, \"Failed to convert value {:a, :b} to atom.\"}\r\n\r\n    iex> Want.Atom.cast(\"10\", exists: true)\r\n    {:error, \"An atom matching the given value does not exist.\"}","ref":"Want.Atom.html#cast/1-examples"},{"type":"function","title":"Want.Atom.cast/2","doc":"","ref":"Want.Atom.html#cast/2"},{"type":"type","title":"Want.Atom.result/0","doc":"","ref":"Want.Atom.html#t:result/0"},{"type":"module","title":"Want.Boolean","doc":"Performs type conversions to boolean values.","ref":"Want.Boolean.html"},{"type":"function","title":"Want.Boolean.cast/1","doc":"Cast a value to a boolean.","ref":"Want.Boolean.html#cast/1"},{"type":"function","title":"Examples - Want.Boolean.cast/1","doc":"iex> Want.Boolean.cast(\"true\")\n    {:ok, true}\n\n    iex> Want.Boolean.cast(\"false\")\n    {:ok, false}\n\n    iex> Want.Boolean.cast(\"TRUE\")\n    {:ok, true}\n\n    iex> Want.Boolean.cast(1.0)\n    {:ok, true}\n\n    iex> Want.Boolean.cast(0)\n    {:ok, false}\n\n    iex> Want.Boolean.cast({:a, :b})\n    {:error, \"Failed to convert value {:a, :b} to boolean.\"}","ref":"Want.Boolean.html#cast/1-examples"},{"type":"function","title":"Want.Boolean.cast/2","doc":"","ref":"Want.Boolean.html#cast/2"},{"type":"type","title":"Want.Boolean.result/0","doc":"","ref":"Want.Boolean.html#t:result/0"},{"type":"module","title":"Want.Date","doc":"Provides conversions to and from Elixir Date structs.","ref":"Want.Date.html"},{"type":"function","title":"Want.Date.cast/1","doc":"Cast a value to an date.","ref":"Want.Date.html#cast/1"},{"type":"function","title":"Options - Want.Date.cast/1","doc":"* `:decode` - If set to `:uri`, executes a URI decode on the input value before casting it.","ref":"Want.Date.html#cast/1-options"},{"type":"function","title":"Examples - Want.Date.cast/1","doc":"iex> Want.Date.cast(\"2022-03-04\")\n    {:ok, %Date{year: 2022, month: 03, day: 04}}","ref":"Want.Date.html#cast/1-examples"},{"type":"function","title":"Want.Date.cast/2","doc":"","ref":"Want.Date.html#cast/2"},{"type":"type","title":"Want.Date.result/0","doc":"","ref":"Want.Date.html#t:result/0"},{"type":"module","title":"Want.DateTime","doc":"Provides conversions to and from Elixir DateTime structs.","ref":"Want.DateTime.html"},{"type":"function","title":"Want.DateTime.cast/2","doc":"Cast an input to a DateTime.","ref":"Want.DateTime.html#cast/2"},{"type":"function","title":"Options - Want.DateTime.cast/2","doc":"","ref":"Want.DateTime.html#cast/2-options"},{"type":"function","title":"Options - Want.DateTime.cast/2","doc":"* `:decode` - If set to `:uri`, executes a URI decode on the input value before casting it.\n  * `:format` - If set to `:unix_ms`, interprets the input as a unix timestamp with millisecond accuracy. Otherwise as seconds since the epoch","ref":"Want.DateTime.html#cast/2-options"},{"type":"function","title":"Examples - Want.DateTime.cast/2","doc":"iex> Want.DateTime.cast(\"2024-11-18T09:51:39.0Z\", [])\n    {:ok, %DateTime{time_zone: \"Etc/UTC\", zone_abbr: \"UTC\", utc_offset: 0, std_offset: 0, year: 2024, month: 11, day: 18, hour: 09, minute: 51, second: 39, microsecond: {0, 1}}}\n\n    iex> Want.DateTime.cast(1731671182000, format: :unix_ms)\n    {:ok, %DateTime{time_zone: \"Etc/UTC\", zone_abbr: \"UTC\", utc_offset: 0, std_offset: 0, year: 2024, month: 11, day: 15, hour: 11, minute: 46, second: 22}}\n\n    iex> Want.DateTime.cast(1731671182, [])\n    {:ok, %DateTime{time_zone: \"Etc/UTC\", zone_abbr: \"UTC\", utc_offset: 0, std_offset: 0, year: 2024, month: 11, day: 15, hour: 11, minute: 46, second: 22}}","ref":"Want.DateTime.html#cast/2-examples"},{"type":"type","title":"Want.DateTime.result/0","doc":"","ref":"Want.DateTime.html#t:result/0"},{"type":"type","title":"Want.DateTime.t/0","doc":"","ref":"Want.DateTime.html#t:t/0"},{"type":"protocol","title":"Want.Dump","doc":"Behaviour for type casting modules.","ref":"Want.Dump.html"},{"type":"function","title":"Want.Dump.dump/2","doc":"Dumps an incoming value to an output type.","ref":"Want.Dump.html#dump/2"},{"type":"type","title":"Want.Dump.t/0","doc":"All the types that implement this protocol.","ref":"Want.Dump.html#t:t/0"},{"type":"module","title":"Want.Enum","doc":"Provides type conversions to enumerations.","ref":"Want.Enum.html"},{"type":"function","title":"Want.Enum.cast/2","doc":"Cast a given value to an enum value. The given options keyword list must\r\ninclude an array of valid enum values under the :valid key, otherwise the\r\nfunction will return an error tuple.","ref":"Want.Enum.html#cast/2"},{"type":"function","title":"Options - Want.Enum.cast/2","doc":"* `:valid` - List of valid enum values. The input must loosely match one of these.","ref":"Want.Enum.html#cast/2-options"},{"type":"function","title":"Examples - Want.Enum.cast/2","doc":"iex> Want.Enum.cast(\"hello\", valid: [:hello, :world])\r\n    {:ok, :hello}\r\n\r\n    iex> Want.Enum.cast(\"hello\", valid: [\"hello\", :world])\r\n    {:ok, \"hello\"}","ref":"Want.Enum.html#cast/2-examples"},{"type":"function","title":"Want.Enum.cast/3","doc":"","ref":"Want.Enum.html#cast/3"},{"type":"type","title":"Want.Enum.result/0","doc":"","ref":"Want.Enum.html#t:result/0"},{"type":"module","title":"Want.Float","doc":"Performs type conversions to float values.","ref":"Want.Float.html"},{"type":"function","title":"Want.Float.cast/1","doc":"Cast a value to a float.","ref":"Want.Float.html#cast/1"},{"type":"function","title":"Options - Want.Float.cast/1","doc":"* `:max` - Maximum allowable float value.\r\n  * `:min` - Minimum allowable float value.","ref":"Want.Float.html#cast/1-options"},{"type":"function","title":"Examples - Want.Float.cast/1","doc":"iex> Want.Float.cast(\"1\")\r\n    {:ok, 1.0}\r\n\r\n    iex> Want.Float.cast(1.0)\r\n    {:ok, 1.0}\r\n\r\n    iex> Want.Float.cast(:'1')\r\n    {:ok, 1.0}\r\n\r\n    iex> Want.Float.cast({:a, :b})\r\n    {:error, \"Failed to convert value {:a, :b} to float.\"}\r\n\r\n    iex> Want.Float.cast(\"10\", max: 3.0)\r\n    {:error, \"Float value exceeds maximum 3.0.\"}\r\n\r\n    iex> Want.Float.cast(1.0, min: 3.0)\r\n    {:error, \"Float value below minimum 3.0.\"}","ref":"Want.Float.html#cast/1-examples"},{"type":"function","title":"Want.Float.cast/2","doc":"","ref":"Want.Float.html#cast/2"},{"type":"type","title":"Want.Float.result/0","doc":"","ref":"Want.Float.html#t:result/0"},{"type":"module","title":"Want.Integer","doc":"Manages conversions to and from integers.","ref":"Want.Integer.html"},{"type":"function","title":"Want.Integer.cast/1","doc":"Cast a value to an integer.","ref":"Want.Integer.html#cast/1"},{"type":"function","title":"Options - Want.Integer.cast/1","doc":"* `:max` - Maximum allowable integer value.\r\n  * `:min` - Minimum allowable integer value.","ref":"Want.Integer.html#cast/1-options"},{"type":"function","title":"Examples - Want.Integer.cast/1","doc":"iex> Want.Integer.cast(\"1\")\r\n    {:ok, 1}\r\n\r\n    iex> Want.Integer.cast(1.0)\r\n    {:ok, 1}\r\n\r\n    iex> Want.Integer.cast(:'1')\r\n    {:ok, 1}\r\n\r\n    iex> Want.Integer.cast({:a, :b})\r\n    {:error, \"Failed to convert value {:a, :b} to integer.\"}\r\n\r\n    iex> Want.Integer.cast(\"10\", max: 3)\r\n    {:error, \"Integer value exceeds maximum 3.\"}\r\n\r\n    iex> Want.Integer.cast(1.0, min: 3)\r\n    {:error, \"Integer value below minimum 3.\"}","ref":"Want.Integer.html#cast/1-examples"},{"type":"function","title":"Want.Integer.cast/2","doc":"","ref":"Want.Integer.html#cast/2"},{"type":"type","title":"Want.Integer.result/0","doc":"","ref":"Want.Integer.html#t:result/0"},{"type":"module","title":"Want.Keyword","doc":"Manages conversions to and from keyword lists.","ref":"Want.Keyword.html"},{"type":"function","title":"Want.Keyword.cast/2","doc":"Cast an incoming keyword list or map to an output keyword list using the\r\nprovided schema to control conversion rules and validations.","ref":"Want.Keyword.html#cast/2"},{"type":"function","title":"Examples - Want.Keyword.cast/2","doc":"iex> Want.Keyword.cast(%{\"id\" => 1}, %{id: [type: :integer]})\r\n    {:ok, [id: 1]}\r\n\r\n    iex> Want.Keyword.cast(%{\"archived\" => \"true\"}, %{archived: [type: :boolean, default: false]})\r\n    {:ok, [archived: true]}\r\n\r\n    iex> Want.Keyword.cast(%{\"archived\" => \"false\"}, %{archived: [type: :boolean, default: false]})\r\n    {:ok, [archived: false]}\r\n\r\n    iex> Want.Keyword.cast(%{}, %{archived: [type: :boolean, default: false]})\r\n    {:ok, [archived: false]}\r\n\r\n    iex> Want.Keyword.cast(%{}, %{id: [type: :integer, default: 1]})\r\n    {:ok, [id: 1]}\r\n\r\n    iex> Want.Keyword.cast(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]})\r\n    {:ok, [id: 1]}\r\n\r\n    iex> Want.Keyword.cast(%{\"hello\" => \"world\", \"foo\" => \"bar\"}, %{hello: [], foo: [type: :atom]})\r\n    {:ok, [hello: \"world\", foo: :bar]}\r\n\r\n    iex> Want.Keyword.cast(%{\"hello\" => \"world\"}, %{hello: [], foo: [required: true]})\r\n    {:error, \"Failed to cast key foo (key :foo not found) and no default value provided.\"}\r\n\r\n    iex> Want.Map.cast(%{\"datetime\" => DateTime.from_unix!(0)}, %{datetime: [type: :datetime]})\r\n    {:ok, %{datetime: DateTime.from_unix!(0)}}\r\n\r\n    iex> Want.Map.cast(%{\"datetime\" => \"1970-01-01T00:00:00Z\"}, %{datetime: [type: :datetime]})\r\n    {:ok, %{datetime: DateTime.from_unix!(0)}}\r\n\r\n    iex> Want.Keyword.cast(%{\"hello\" => \"world\"}, %{hello: [], foo: []})\r\n    {:ok, [hello: \"world\"]}\r\n\r\n    iex> Want.Keyword.cast(%{\"hello\" => \"world\"}, %{hello: [type: :enum, valid: [:world]]})\r\n    {:ok, [hello: :world]}\r\n\r\n    iex> Want.Keyword.cast(%{\"hello\" => %{\"foo\" => \"bar\"}}, %{hello: %{foo: [type: :atom]}})\r\n    {:ok, [hello: [foo: :bar]]}\r\n\r\n    iex> Want.Keyword.cast(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]}, merge: [id: 2])\r\n    {:ok, [id: 2]}\r\n\r\n    iex> Want.Keyword.cast(%{\"id\" => \"bananas\"}, %{id: [type: :any]})\r\n    {:ok, [id: \"bananas\"]}\r\n\r\n    iex> Want.Keyword.cast(%{\"a\" => %{\"b\" => %{\"c\" => 100}}}, %{id: [type: :integer, from: {\"a\", \"b\", \"c\"}]})\r\n    {:ok, [id: 100]}\r\n\r\n    iex> Want.Keyword.cast(%{\"a\" => [1, 2, 3, 4]}, %{a: [type: {:array, :integer}]})\r\n    {:ok, [a: [1, 2, 3, 4]]}\r\n\r\n    iex> Want.Keyword.cast(%{\"a\" => %{\"b\" => %{\"c\" => 100}}}, %{id: [type: :integer, from: {\"a\", \"b\", \"c\"}, transform: fn x -> x * 2 end]})\r\n    {:ok, [id: 200]}","ref":"Want.Keyword.html#cast/2-examples"},{"type":"function","title":"Want.Keyword.cast/3","doc":"","ref":"Want.Keyword.html#cast/3"},{"type":"type","title":"Want.Keyword.enumerable/0","doc":"","ref":"Want.Keyword.html#t:enumerable/0"},{"type":"type","title":"Want.Keyword.input/0","doc":"","ref":"Want.Keyword.html#t:input/0"},{"type":"type","title":"Want.Keyword.key/0","doc":"","ref":"Want.Keyword.html#t:key/0"},{"type":"type","title":"Want.Keyword.opts/0","doc":"","ref":"Want.Keyword.html#t:opts/0"},{"type":"type","title":"Want.Keyword.result/0","doc":"","ref":"Want.Keyword.html#t:result/0"},{"type":"type","title":"Want.Keyword.schema/0","doc":"","ref":"Want.Keyword.html#t:schema/0"},{"type":"module","title":"Want.List","doc":"Manages conversions to and from lists.","ref":"Want.List.html"},{"type":"function","title":"Want.List.cast/1","doc":"Cast an input into a list. By default this function will simply break up the input into list elements, but\nfurther casting and validation of elements can be performed by providing an `element` option. The separator\nused to split the list defaults to the comma character and this can be controlled using the `separator` option.","ref":"Want.List.html#cast/1"},{"type":"function","title":"Options - Want.List.cast/1","doc":"* `:separator` - Determines the character(s) used to separate list items. Defaults to the comma character.\n  * `:element` - Provides the ability to further control how list elements are cast and validated. Similar to the\n  `map` and `keywords` functions, accepts a keyword list with its own `:type` field and validation options.","ref":"Want.List.html#cast/1-options"},{"type":"function","title":"Examples - Want.List.cast/1","doc":"iex> Want.List.cast(\"1\")\n    {:ok, [\"1\"]}\n\n    iex> Want.List.cast(\"1\", element: [type: :integer])\n    {:ok, [1]}\n\n    iex> Want.List.cast(\"1,2,3,4\", element: [type: :integer])\n    {:ok, [1, 2, 3, 4]}\n\n    iex> Want.List.cast(\"1:2:3:4\", separator: \":\", element: [type: :integer])\n    {:ok, [1, 2, 3, 4]}\n\n    iex> Want.List.cast(\"hello:world\", separator: \":\", element: [type: :enum, valid: [:hello, :world]])\n    {:ok, [:hello, :world]}\n\n    iex> Want.List.cast(\"hello:world\", separator: \":\", element: [type: :enum, valid: [:hello]])\n    {:ok, [:hello]}","ref":"Want.List.html#cast/1-examples"},{"type":"function","title":"Want.List.cast/2","doc":"","ref":"Want.List.html#cast/2"},{"type":"type","title":"Want.List.element/0","doc":"","ref":"Want.List.html#t:element/0"},{"type":"type","title":"Want.List.result/0","doc":"","ref":"Want.List.html#t:result/0"},{"type":"module","title":"Want.Map","doc":"Manages conversions to and from maps.","ref":"Want.Map.html"},{"type":"function","title":"Want.Map.cast/2","doc":"Cast an incoming keyword list or map to an output map using the\r\nprovided schema to control conversion rules and validations.","ref":"Want.Map.html#cast/2"},{"type":"function","title":"Options - Want.Map.cast/2","doc":"* `:merge` - Provide a map matching the given schema that contains default values to be\r\n    used if the input value does not contain a particular field. Useful when updating a map\r\n    with new inputs without overwriting all fields.","ref":"Want.Map.html#cast/2-options"},{"type":"function","title":"Examples - Want.Map.cast/2","doc":"iex> Want.Map.cast(%{\"id\" => 1}, %{id: [type: :integer]})\r\n    {:ok, %{id: 1}}\r\n\r\n    iex> Want.Map.cast(%{}, %{id: [type: :integer, default: 1]})\r\n    {:ok, %{id: 1}}\r\n\r\n    iex> Want.Map.cast(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]})\r\n    {:ok, %{id: 1}}\r\n\r\n    iex> Want.Map.cast(%{\"archived\" => \"true\"}, %{archived: [type: :boolean, default: false]})\r\n    {:ok, %{archived: true}}\r\n\r\n    iex> Want.Map.cast(%{\"archived\" => \"false\"}, %{archived: [type: :boolean, default: false]})\r\n    {:ok, %{archived: false}}\r\n\r\n    iex> Want.Map.cast(%{}, %{archived: [type: :boolean, default: false]})\r\n    {:ok, %{archived: false}}\r\n\r\n    iex> Want.Map.cast(%{\"hello\" => \"world\", \"foo\" => \"bar\"}, %{hello: [], foo: [type: :atom]})\r\n    {:ok, %{hello: \"world\", foo: :bar}}\r\n\r\n    iex> Want.Map.cast(%{\"date\" => %Date{year: 2022, month: 01, day: 02}}, %{date: [type: :date]})\r\n    {:ok, %{date: %Date{year: 2022, month: 01, day: 02}}}\r\n\r\n    iex> Want.Map.cast(%{\"date\" => \"2022-01-02\"}, %{date: [type: :date]})\r\n    {:ok, %{date: %Date{year: 2022, month: 01, day: 02}}}\r\n\r\n    iex> Want.Map.cast(%{\"hello\" => \"world\"}, %{hello: [], foo: [required: true]})\r\n    {:error, \"Failed to cast key foo (key :foo not found) and no default value provided.\"}\r\n\r\n    iex> Want.Map.cast(%{\"c\" => \"world\"}, %{foo: [type: :string, from: [\"a\", \"b\", \"c\"]]})\r\n    {:ok, %{foo: \"world\"}}\r\n\r\n    iex> Want.Map.cast(%{\"hello\" => \"world\"}, %{hello: [type: :enum, valid: [:world]]})\r\n    {:ok, %{hello: :world}}\r\n\r\n    iex> Want.Map.cast(%{\"hello\" => \"world\"}, %{hello: [], foo: []})\r\n    {:ok, %{hello: \"world\"}}\r\n\r\n    iex> Want.Map.cast(%{\"hello\" => %{\"foo\" => \"bar\"}}, %{hello: %{foo: [type: :atom]}})\r\n    {:ok, %{hello: %{foo: :bar}}}\r\n\r\n    iex> Want.Map.cast(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]}, merge: %{id: 2})\r\n    {:ok, %{id: 2}}\r\n\r\n    iex> Want.Map.cast(%{\"id\" => \"bananas\"}, %{id: [type: :any]})\r\n    {:ok, %{id: \"bananas\"}}\r\n\r\n    iex> Want.Map.cast(%{\"a\" => %{\"b\" => %{\"c\" => 100}}}, %{id: [type: :integer, from: {\"a\", \"b\", \"c\"}]})\r\n    {:ok, %{id: 100}}\r\n\r\n    iex> Want.Map.cast(%{\"a\" => [1, 2, 3, 4]}, %{a: [type: {:array, :integer}]})\r\n    {:ok, %{a: [1, 2, 3, 4]}}\r\n\r\n    iex> Want.Map.cast(%{\"a\" => %{\"b\" => %{\"c\" => 100}}}, %{id: [type: :integer, from: {\"a\", \"b\", \"c\"}, transform: fn x -> x * 2 end]})\r\n    {:ok, %{id: 200}}","ref":"Want.Map.html#cast/2-examples"},{"type":"function","title":"Want.Map.cast/3","doc":"","ref":"Want.Map.html#cast/3"},{"type":"type","title":"Want.Map.enumerable/0","doc":"","ref":"Want.Map.html#t:enumerable/0"},{"type":"type","title":"Want.Map.input/0","doc":"","ref":"Want.Map.html#t:input/0"},{"type":"type","title":"Want.Map.key/0","doc":"","ref":"Want.Map.html#t:key/0"},{"type":"type","title":"Want.Map.opts/0","doc":"","ref":"Want.Map.html#t:opts/0"},{"type":"type","title":"Want.Map.result/0","doc":"","ref":"Want.Map.html#t:result/0"},{"type":"type","title":"Want.Map.schema/0","doc":"","ref":"Want.Map.html#t:schema/0"},{"type":"module","title":"Want.Shape","doc":"Provides macros for declaring an Ecto-like schema definition that can be used\nto cast incoming data. Most of the macro logic here was adapted from `Ecto.Schema`.","ref":"Want.Shape.html"},{"type":"function","title":"Want.Shape.cast/2","doc":"Cast incoming data based on a Shape definition.","ref":"Want.Shape.html#cast/2"},{"type":"function","title":"Want.Shape.cast!/2","doc":"Cast incoming data based on a Shape definition. Raises on error.","ref":"Want.Shape.html#cast!/2"},{"type":"function","title":"Want.Shape.cast_all/2","doc":"Cast a list of maps to a list of Shapes.","ref":"Want.Shape.html#cast_all/2"},{"type":"function","title":"Want.Shape.cast_all!/2","doc":"Cast a list of maps to a list of Shapes.","ref":"Want.Shape.html#cast_all!/2"},{"type":"macro","title":"Want.Shape.field/3","doc":"Define a field within a shape.","ref":"Want.Shape.html#field/3"},{"type":"function","title":"Want.Shape.is_shape?/1","doc":"Determine whether the given module represents a shape.","ref":"Want.Shape.html#is_shape?/1"},{"type":"macro","title":"Want.Shape.shape/1","doc":"Define a schema. Generates a struct definition for the current module that includes the data\nneeded to correctly cast incoming JSON/map data into that struct, including field sourcing, type\nconversions, etc.","ref":"Want.Shape.html#shape/1"},{"type":"module","title":"Want.Sort","doc":"Specialized functions for dealing with sort parameters in\r\nPhoenix requests.","ref":"Want.Sort.html"},{"type":"function","title":"Want.Sort.cast/2","doc":"","ref":"Want.Sort.html#cast/2"},{"type":"function","title":"Want.Sort.cast/3","doc":"","ref":"Want.Sort.html#cast/3"},{"type":"type","title":"Want.Sort.direction/0","doc":"","ref":"Want.Sort.html#t:direction/0"},{"type":"type","title":"Want.Sort.result/0","doc":"","ref":"Want.Sort.html#t:result/0"},{"type":"type","title":"Want.Sort.sort/0","doc":"","ref":"Want.Sort.html#t:sort/0"},{"type":"module","title":"Want.String","doc":"Manages conversions to and from strings.","ref":"Want.String.html"},{"type":"function","title":"Want.String.cast/1","doc":"Casts a given value to a string.","ref":"Want.String.html#cast/1"},{"type":"function","title":"Options - Want.String.cast/1","doc":"* `:max` - Maximum allowable string length.\r\n  * `:min` - Minimum allowable string length.\r\n  * ':decode' - Currently only supports :uri; runs URI.decode on the input value\r\n  * `:matches` - The resulting string must match the given regex.","ref":"Want.String.html#cast/1-options"},{"type":"function","title":"Examples - Want.String.cast/1","doc":"iex> Want.String.cast(1)\r\n    {:ok, \"1\"}\r\n\r\n    iex> Want.String.cast({:a, :b})\r\n    {:error, \"Failed to convert value {:a, :b} to string.\"}\r\n\r\n    iex> Want.String.cast(:hello, max: 3)\r\n    {:error, \"String length exceeds maximum of 3.\"}\r\n\r\n    iex> Want.String.cast(:a, min: 3)\r\n    {:error, \"String length below minimum of 3.\"}\r\n\r\n    iex> Want.String.cast(\"hello%20world\", decode: :uri)\r\n    {:ok, \"hello world\"}\r\n\r\n    iex> Want.String.cast(:a, matches: ~r/a/)\r\n    {:ok, \"a\"}","ref":"Want.String.html#cast/1-examples"},{"type":"function","title":"Want.String.cast/2","doc":"","ref":"Want.String.html#cast/2"},{"type":"type","title":"Want.String.result/0","doc":"","ref":"Want.String.html#t:result/0"},{"type":"behaviour","title":"Want.Type","doc":"Behaviour for type casting modules.","ref":"Want.Type.html"},{"type":"callback","title":"Want.Type.cast/2","doc":"","ref":"Want.Type.html#c:cast/2"},{"type":"type","title":"Want.Type.opts/0","doc":"","ref":"Want.Type.html#t:opts/0"},{"type":"type","title":"Want.Type.schema/0","doc":"","ref":"Want.Type.html#t:schema/0"},{"type":"protocol","title":"Want.Update","doc":"Behaviour for type casting modules.","ref":"Want.Update.html"},{"type":"function","title":"Want.Update.update/2","doc":"Updates an existing value with a new one","ref":"Want.Update.html#update/2"},{"type":"type","title":"Want.Update.t/0","doc":"All the types that implement this protocol.","ref":"Want.Update.html#t:t/0"},{"type":"extras","title":"Want","doc":"# Want [![Hex Version](https://img.shields.io/hexpm/v/want.svg)](https://hex.pm/packages/want) [![Hex Docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/want/)\n\nErlang and Elixir library for performing easy type conversions. The Elixir interface\nis now a lot more complex than the Erlang one; supporting schema-based conversions between\ncontainer types along with validation and default values.","ref":"readme.html"},{"type":"extras","title":"Installation - Want","doc":"The package can be installed by adding `want` to your list of dependencies\nin `mix.exs`:\n\n```elixir\ndef deps do\n  [{:want, \"~> 1.14\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Want","doc":"Conversion between types in Erlang.\n\n```erlang\n% String to integer\n1 = want:integer( \"1\" ),\n% String to float\n1.0 = want:float( \"1\" ),\n% Integer to String\n\"1.0\" = want:string( 1 ),\n% Integer to binary\n<<\"1.0\">> = want:binary( 1 ),\n% String to boolean\ntrue = want:boolean( \"true\" ),\n```\n\nConversion between types in Elixir.\n\n```elixir\n# String to integer\n{:ok, 1} = Want.integer(\"1\")\n# String to integer, raise on failure\n1 = Want.integer!(\"1\")\n# String to float\n{:ok, 1.0} = Want.float(\"1\")\n# String to float, raise on failure\n1.0 = Want.float!(\"1\")\n# Integer to string\n{:ok, \"1\"} = Want.string(1)\n# Integer to string, raise on failure\n\"1\" = Want.string!(1)\n# String to boolean\n{:ok, true} = Want.boolean(\"true\")\n{:ok, false} = Want.boolean(\"FALSE\")\n# String to boolean, raise on failure\ntrue = Want.boolean!(\"true\")\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Complex Type Conversions in Elixir - Want","doc":"```elixir\n\n# Binary to Integer with default value used on conversion failure\n{:ok, 1} = Want.integer(\"foo\", default: 1)\n# Map to Keyword List with default values used on conversion failure\n{:ok, [id: 1]} = Want.keywords(%{\"id\" => \"bananas\"}, %{id: [type: :integer, default: 1]})\n# Map to Map with field type conversions\n{:ok, %{hello: \"world\", foo: :bar}} = Want.map(%{\"hello\" => \"world\", \"foo\" => \"bar\"}, %{hello: [], foo: [type: :atom]}) \n# Nested Key Extraction\n{:ok, %{id: 100}} = Want.Map.cast(%{\"a\" => %{\"b\" => %{\"c\" => 100}}}, %{id: [type: :integer, from: {\"a\", \"b\", \"c\"}]})\n# Key extraction from multiple potential fields, first match wins\n{:ok, %{id: 100}} = Want.Map.cast(%{\"b\" => \"100\", \"c\" => \"200\"}, %{id: [type: :integer, from: [\"a\", \"b\", \"c\"]]})\n```","ref":"readme.html#complex-type-conversions-in-elixir"},{"type":"extras","title":"Shape Definitions - Want","doc":"It can be useful to define the shape of your data, similar to how `Ecto.Schema` works; simultaneously defining a struct and\nthe means to parse it from incoming data. You can use `Want.Shape` to do this.\n\n```elixir\ndefmodule MyModule do\n    use Want.Shape\n\n    shape do\n        field :is_valid,    :boolean,   default: false\n        field :count,       :integer,   default: 0\n        field :from,        :string,    from: \"FromField\"\n        field :multi_from,  :integer,   from: [\"a\", {\"b\", \"c\", \"d\"}], default: 0\n    end\nend\n\n{:ok, %MyModule{is_valid: true, count: 10, from: \"Foo\", multi_from: 10}} = MyModule.cast(%{\n    \"is_valid\"  => \"true\",\n    \"count\"     => \"10\",\n    \"from\"      => \"Foo\",\n    \"b\"         => %{\n        \"c\" => %{\n            \"d\" => 10\n        }\n    }\n})\n\n```","ref":"readme.html#shape-definitions"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.14.1 (17.11.2024) - Changelog","doc":"* Add explicit support for boolean conversion via `Want.boolean/1`.\n* Update README and documentation for better display via hexdocs.","ref":"changelog.html#1-14-1-17-11-2024"},{"type":"extras","title":"1.15.5 (18.11.2024) - Changelog","doc":"* Various fixes to Shape casting\n* Added `:transform` option to `Want.map`, `Want.keywords`, and `Want.shape` field options, allowing a transformation to be applied to cast values.","ref":"changelog.html#1-15-5-18-11-2024"},{"type":"extras","title":"1.15.6 (19.11.2024) - Changelog","doc":"* Adds `Want.Shape.cast_all/2` and `Want.Shape.cast_all!/2`.","ref":"changelog.html#1-15-6-19-11-2024"},{"type":"extras","title":"LICENSE","doc":"The MIT License (MIT)\n\nCopyright (c) 2016 Warren Kenny\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}